==> haskell-data-default-instances-base-0.1.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-base
version:              0.1.0.1
visibility:           public
id:                   data-default-instances-base-0.1.0.1-6p22lohWR4x3cQQKHiIED5
key:                  data-default-instances-base-0.1.0.1-6p22lohWR4x3cQQKHiIED5
license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in base
category:             Data
abi:                  2c517644c1dd1b46c68d97b5f2c9341a
exposed:              True
exposed-modules:      Data.Default.Instances.Base
import-dirs:
    /usr/lib/ghc-8.10.1/site-local/data-default-instances-base-0.1.0.1

library-dirs:
    /usr/lib/ghc-8.10.1/site-local/data-default-instances-base-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/data-default-instances-base-0.1.0.1

hs-libraries:
    HSdata-default-instances-base-0.1.0.1-6p22lohWR4x3cQQKHiIED5

depends:
    base-4.14.0.0 data-default-class-0.1.2.0-AZTcEqCsR4uCdCN1ROsSjZ

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-base/html/data-default-instances-base.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-base-0.1.0.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-base
version:              0.1.0.1
visibility:           public
id:                   data-default-instances-base-0.1.0.1-H7K89O0pwSsaUcbgVYm82
key:                  data-default-instances-base-0.1.0.1-H7K89O0pwSsaUcbgVYm82
license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in base
category:             Data
abi:                  ba841d4f343f0d2820afe9c8e9613d6b
exposed:              True
exposed-modules:      Data.Default.Instances.Base
import-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-default-instances-base-0.1.0.1

library-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-default-instances-base-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/data-default-instances-base-0.1.0.1

hs-libraries:         HSdata-default-instances-base-0.1.0.1-H7K89O0pwSsaUcbgVYm82
depends:
    base-4.14.1.0 data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-base/html/data-default-instances-base.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
